package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseDeviceInfo;

/**
 * 设备基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-22
 */
public interface BaseDeviceInfoMapper 
{
    /**
     * 查询设备基础信息
     * 
     * @param objid 设备基础信息ID
     * @return 设备基础信息
     */
    public BaseDeviceInfo selectBaseDeviceInfoById(Long objid);

    /**
     * 查询设备基础信息列表
     * 
     * @param baseDeviceInfo 设备基础信息
     * @return 设备基础信息集合
     */
    public List<BaseDeviceInfo> selectBaseDeviceInfoList(BaseDeviceInfo baseDeviceInfo);

    /**
     * 新增设备基础信息
     * 
     * @param baseDeviceInfo 设备基础信息
     * @return 结果
     */
    public int insertBaseDeviceInfo(BaseDeviceInfo baseDeviceInfo);

    /**
     * 修改设备基础信息
     * 
     * @param baseDeviceInfo 设备基础信息
     * @return 结果
     */
    public int updateBaseDeviceInfo(BaseDeviceInfo baseDeviceInfo);

    /**
     * 删除设备基础信息
     * 
     * @param objid 设备基础信息ID
     * @return 结果
     */
    public int deleteBaseDeviceInfoById(Long objid);

    /**
     * 批量删除设备基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseDeviceInfoByIds(String[] objids);

}
